<?php
/**
 * This file belongs to the YIT Plugin Framework.
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'YWRFD_Coupon_Mail' ) ) {

	/**
	 * Implements Coupon Mail for YWRFD plugin
	 *
	 * @class   YWRFD_Coupon_Mail
	 * @since   1.0.0
	 * @author  Your Inspiration Themes
	 * @extends WC_Email
	 *
	 * @package Yithemes
	 */
	class YWRFD_Coupon_Mail extends WC_Email {

		/**
		 * @var int $mail_body content of the email
		 */
		var $mail_body;

		/**
		 * Constructor
		 *
		 * Initialize email type and set templates paths
		 *
		 * @since   1.0.0
		 * @author  Alberto Ruggiero
		 */
		public function __construct() {

			$this->id             = 'yith-review-for-discounts';
			$this->customer_email = true;
			$this->description    = esc_html__( 'Reward your customers with a gentle discount: approve their reviews and encourage them to purchase again in your shop!', 'yith-woocommerce-review-for-discounts' );
			$this->title          = esc_html__( 'Review For Discounts Emails', 'yith-woocommerce-review-for-discounts' );
			$this->template_base  = YWRFD_TEMPLATE_PATH . '/';
			$this->template_html  = 'emails/coupon-email.php';
			$this->template_plain = 'emails/plain/coupon-email.php';
			$this->enabled        = 'yes';

			parent::__construct();

		}

		/**
		 * Trigger email send
		 *
		 * @param   $mail_body
		 * @param   $mail_subject
		 * @param   $mail_address
		 * @param   $type
		 * @param   $vendor_id
		 *
		 * @return  bool
		 * @since   1.0.0
		 *
		 * @author  Alberto Ruggiero
		 */
		public function trigger( $mail_body, $mail_subject, $mail_address, $type, $vendor_id = '' ) {

			$this->email_type = get_option( 'ywrfd_email_' . $type . '_type' . ( apply_filters( 'ywrfd_set_vendor_id', '', $vendor_id ) ) );
			$this->heading    = $mail_subject;
			$this->subject    = $mail_subject;
			$this->mail_body  = $mail_body;
			$this->recipient  = $mail_address;

			if ( ! $this->get_recipient() ) {
				return false;
			}

			return $this->send( $this->get_recipient(), $this->subject, $this->get_content(), $this->get_headers(), "" );

		}

		/**
		 * Send the email.
		 *
		 * @param string $to
		 * @param string $subject
		 * @param string $message
		 * @param string $headers
		 * @param string $attachments
		 *
		 * @return  bool
		 * @since   1.0.0
		 *
		 * @author  Alberto Ruggiero
		 */
		public function send( $to, $subject, $message, $headers, $attachments ) {

			add_filter( 'wp_mail_from', array( $this, 'get_from_address' ) );
			add_filter( 'wp_mail_from_name', array( $this, 'get_from_name' ) );
			add_filter( 'wp_mail_content_type', array( $this, 'get_content_type' ) );

			$message = apply_filters( 'woocommerce_mail_content', $this->style_inline( $message ) );

			if ( defined( 'YWRFD_PREMIUM' ) && get_option( 'ywrfd_mandrill_enable' ) == 'yes' ) {

				$return = YWRFD_Mandrill()->send_email( $to, $subject, $message, $headers, $attachments );

			} else {

				$return = wp_mail( $to, $subject, $message, $headers, $attachments );

			}

			remove_filter( 'wp_mail_from', array( $this, 'get_from_address' ) );
			remove_filter( 'wp_mail_from_name', array( $this, 'get_from_name' ) );
			remove_filter( 'wp_mail_content_type', array( $this, 'get_content_type' ) );

			return $return;

		}

		/**
		 * Get HTML content
		 *
		 * @return  string
		 * @since   1.0.0
		 * @author  Alberto Ruggiero
		 */
		public function get_content_html() {

			ob_start();

			wc_get_template( $this->template_html, array(
				'email_heading' => $this->get_heading(),
				'mail_body'     => $this->mail_body,
				'sent_to_admin' => false,
				'plain_text'    => false,
				'email'         => $this
			), false, $this->template_base );

			return ob_get_clean();

		}

		/**
		 * Get Plain content
		 *
		 * @return  string
		 * @since   1.0.0
		 * @author  Alberto Ruggiero
		 */
		public function get_content_plain() {

			ob_start();

			wc_get_template( $this->template_plain, array(
				'email_heading' => $this->get_heading(),
				'mail_body'     => $this->mail_body,
				'sent_to_admin' => false,
				'plain_text'    => true
			), false, $this->template_base );

			return ob_get_clean();

		}

		/**
		 * Get email content type.
		 *
		 * @return  string
		 * @since   1.0.2
		 * @author  Alberto Ruggiero
		 */
		public function get_content_type( $default = '' ) {

			return 'text/html';

		}

		/**
		 * Checks if this email is enabled and will be sent.
		 *
		 * @return  bool
		 * @since   1.0.2
		 * @author  Alberto Ruggiero
		 */
		public function is_enabled() {
			return true;
		}

		/**
		 * Initialise Settings Form Fields
		 *
		 * @return  void
		 * @since   1.0.0
		 * @author  Alberto Ruggiero
		 */
		public function init_form_fields() {

		}

	}

}

return new YWRFD_Coupon_Mail();